==> pybankid-1.0.1.tar.gz: pybankid-1.0.1/tests/test_exceptions.py <==
from collections import namedtuple

import pytest

import bankid


@pytest.mark.parametrize(
    "exception_class,rfa",
    [
        (bankid.exceptions.AlreadyInProgressError, 4),
        (bankid.exceptions.InvalidParametersError, None),
        (bankid.exceptions.UnauthorizedError, None),
        (bankid.exceptions.NotFoundError, None),
        (bankid.exceptions.RequestTimeoutError, 5),
        (bankid.exceptions.InternalError, 5),
        (bankid.exceptions.MaintenanceError, 5),
        (bankid.exceptions.BankIDError, None),
    ],
)
def test_exceptions(exception_class, rfa):
    e = exception_class()
    assert e.rfa == rfa
    assert isinstance(e, bankid.exceptions.BankIDError)


@pytest.mark.parametrize(
    "exception_class,error_code",
    [
        (bankid.exceptions.AlreadyInProgressError, "alreadyInProgress"),
        (bankid.exceptions.InvalidParametersError, "invalidParameters"),
        (bankid.exceptions.UnauthorizedError, "unauthorized"),
        (bankid.exceptions.NotFoundError, "notFound"),
        (bankid.exceptions.RequestTimeoutError, "requestTimeout"),
        (bankid.exceptions.InternalError, "internalError"),
        (bankid.exceptions.MaintenanceError, "maintenance"),
        (bankid.exceptions.BankIDError, "Unknown error code"),
    ],
)
def test_error_class_factory(exception_class, error_code):
    MockResponse = namedtuple("MockResponse", ["json"])
    response = MockResponse(json=lambda: {"errorCode": error_code})
    e_class = bankid.exceptions.get_json_error_class(response)
    assert isinstance(e_class, exception_class)

==> pybankid-1.1.0.tar.gz: pybankid-1.1.0/tests/test_exceptions.py <==
from collections import namedtuple
from typing import Union

import pytest

import bankid


@pytest.mark.parametrize(
    "exception_class,rfa",
    [
        (bankid.exceptions.AlreadyInProgressError, 4),
        (bankid.exceptions.InvalidParametersError, None),
        (bankid.exceptions.UnauthorizedError, None),
        (bankid.exceptions.NotFoundError, None),
        (bankid.exceptions.RequestTimeoutError, 5),
        (bankid.exceptions.InternalError, 5),
        (bankid.exceptions.MaintenanceError, 5),
        (bankid.exceptions.BankIDError, None),
    ],
)
def test_exceptions(exception_class: type[Exception], rfa: Union[int, None]) -> None:
    e = exception_class()
    assert isinstance(e, bankid.exceptions.BankIDError)
    assert e.rfa == rfa


@pytest.mark.parametrize(
    "exception_class,error_code",
    [
        (bankid.exceptions.AlreadyInProgressError, "alreadyInProgress"),
        (bankid.exceptions.InvalidParametersError, "invalidParameters"),
        (bankid.exceptions.UnauthorizedError, "unauthorized"),
        (bankid.exceptions.NotFoundError, "notFound"),
        (bankid.exceptions.RequestTimeoutError, "requestTimeout"),
        (bankid.exceptions.InternalError, "internalError"),
        (bankid.exceptions.MaintenanceError, "maintenance"),
        (bankid.exceptions.BankIDError, "Unknown error code"),
    ],
)
def test_error_class_factory(exception_class: type[Exception], error_code: str) -> None:
    MockResponse = namedtuple("MockResponse", ["json"])
    response = MockResponse(json=lambda: {"errorCode": error_code})
    # error: Argument 1 to "get_json_error_class" has incompatible type "MockResponse@41"; expected "Response"  [arg-type]
    e_class = bankid.exceptions.get_json_error_class(response)  # type: ignore[arg-type]
    assert isinstance(e_class, exception_class)
